@@ -36,6 +36,7 @@ class CourseEditor : public AbstractEditor, private Ui::CourseEditor
     Q_OBJECT
 public:
     explicit CourseEditor(QWidget* parent = 0);
+    ~CourseEditor();
     void setResourceModel(ResourceModel* model);
     void openCourse(DataIndexCourse* dataIndexCourse);
     void clearUndoStackForCourse(DataIndexCourse* course);
@@ -71,7 +72,6 @@ private:
     Lesson* m_currentLesson;
     LessonModel* m_lessonModel;
     bool m_readOnly;
-    LessonTextHighlighter* m_lessonTextHighlighter;
 };
 
 #endif // COURSEEDITOR_H
