@@ -17,10 +17,10 @@
 
 #include "resourcemodel.h"
 
+#include <QIcon>
 #include <QSignalMapper>
 
-#include <KLocale>
-#include <KIcon>
+#include <KLocalizedString>
 #include <KCategorizedSortFilterProxyModel>
 
 ResourceModel::ResourceModel(QObject* parent) :
@@ -29,11 +29,6 @@ ResourceModel::ResourceModel(QObject* parent) :
     m_signalMapper(new QSignalMapper(this))
 {
     connect(m_signalMapper, SIGNAL(mapped(int)), SLOT(emitDataChanged(int)));
-    QHash<int,QByteArray> roleNames = this->roleNames();
-    roleNames.insert(ResourceModel::KeyboardLayoutNameRole, "keyboardLayoutName");
-    roleNames.insert(ResourceModel::PathRole, "path");
-    roleNames.insert(ResourceModel::DataRole, "dataRole");
-    setRoleNames(roleNames);
 }
 
 DataIndex* ResourceModel::dataIndex() const
@@ -56,14 +51,14 @@ void ResourceModel::setDataIndex(DataIndex* dataIndex)
 
         if (m_dataIndex)
         {
-            connect(m_dataIndex, SIGNAL(courseAboutToBeAdded(DataIndexCourse*,int)), SLOT(onCourseAboutToBeAdded(DataIndexCourse*,int)));
-            connect(m_dataIndex, SIGNAL(courseAdded()), SLOT(onResourceAdded()));
-            connect(m_dataIndex, SIGNAL(coursesAboutToBeRemoved(int,int)), SLOT(onCoursesAboutToBeRemoved(int,int)));
-            connect(m_dataIndex, SIGNAL(coursesRemoved()), SLOT(onResourceRemoved()));
-            connect(m_dataIndex, SIGNAL(keyboardLayoutAboutToBeAdded(DataIndexKeyboardLayout*,int)), SLOT(onKeyboardLayoutAboutToBeAdded(DataIndexKeyboardLayout*,int)));
-            connect(m_dataIndex, SIGNAL(keyboardLayoutAdded()), SLOT(onResourceAdded()));
-            connect(m_dataIndex, SIGNAL(keyboardLayoutsAboutToBeRemoved(int,int)), SLOT(onKeyboardLayoutsAboutToBeRemoved(int,int)));
-            connect(m_dataIndex, SIGNAL(keyboardLayoutsRemoved()), SLOT(onResourceRemoved()));
+            connect(m_dataIndex, &DataIndex::courseAboutToBeAdded, this, &ResourceModel::onCourseAboutToBeAdded);
+            connect(m_dataIndex, &DataIndex::courseAdded, this, &ResourceModel::onResourceAdded);
+            connect(m_dataIndex, &DataIndex::coursesAboutToBeRemoved, this, &ResourceModel::onCoursesAboutToBeRemoved);
+            connect(m_dataIndex, &DataIndex::coursesRemoved, this, &ResourceModel::onResourceRemoved);
+            connect(m_dataIndex, &DataIndex::keyboardLayoutAboutToBeAdded, this, &ResourceModel::onKeyboardLayoutAboutToBeAdded);
+            connect(m_dataIndex, &DataIndex::keyboardLayoutAdded, this, &ResourceModel::onResourceAdded);
+            connect(m_dataIndex, &DataIndex::keyboardLayoutsAboutToBeRemoved, this, &ResourceModel::onKeyboardLayoutsAboutToBeRemoved);
+            connect(m_dataIndex, &DataIndex::keyboardLayoutsRemoved, this, &ResourceModel::onResourceRemoved);
         }
 
         for (int i = 0; i < dataIndex->courseCount(); i++)
@@ -94,6 +89,9 @@ QVariant ResourceModel::data(const QModelIndex &index, int role) const
     if (!index.isValid())
         return QVariant();
 
+    if (!m_dataIndex)
+        return QVariant();
+
     if (index.row() > m_dataIndex->courseCount() + m_dataIndex->keyboardLayoutCount())
         return QVariant();
 
@@ -117,9 +115,21 @@ int ResourceModel::rowCount(const QModelIndex &parent) const
     if (parent.isValid())
         return 0;
 
+    if (!m_dataIndex)
+        return 0;
+
     return m_dataIndex->courseCount() + m_dataIndex->keyboardLayoutCount();
 }
 
+QHash<int, QByteArray> ResourceModel::roleNames() const
+{
+    QHash<int, QByteArray> names = QAbstractItemModel::roleNames();
+    names.insert(ResourceModel::KeyboardLayoutNameRole, "keyboardLayoutName");
+    names.insert(ResourceModel::PathRole, "path");
+    names.insert(ResourceModel::DataRole, "dataRole");
+    return names;
+}
+
 void ResourceModel::onCourseAboutToBeAdded(DataIndexCourse* course, int index)
 {
     connectToCourse(course);
@@ -133,6 +143,9 @@ void ResourceModel::onCoursesAboutToBeRemoved(int first, int last)
 
 void ResourceModel::onKeyboardLayoutAboutToBeAdded(DataIndexKeyboardLayout* keyboardLayout, int index)
 {
+    if (!m_dataIndex)
+        return;
+
     const int offset = m_dataIndex->courseCount();
     connectToKeyboardLayout(keyboardLayout);
     beginInsertRows(QModelIndex(), index + offset, index + offset);
@@ -140,6 +153,9 @@ void ResourceModel::onKeyboardLayoutAboutToBeAdded(DataIndexKeyboardLayout* keyb
 
 void ResourceModel::onKeyboardLayoutsAboutToBeRemoved(int first, int last)
 {
+    if (!m_dataIndex)
+        return;
+
     const int offset = m_dataIndex->courseCount();
     beginRemoveRows(QModelIndex(), first + offset, last + offset);
 }
@@ -164,6 +180,9 @@ void ResourceModel::emitDataChanged(int row)
 
 QVariant ResourceModel::courseData(int row, int role) const
 {
+    if (!m_dataIndex)
+        return QVariant();
+
     switch(role)
     {
     case KCategorizedSortFilterProxyModel::CategorySortRole:
@@ -195,6 +214,9 @@ QVariant ResourceModel::courseData(int row, int role) const
 
 QVariant ResourceModel::keyboardLayoutData(int row, int role) const
 {
+    if (!m_dataIndex)
+        return QVariant();
+
     switch(role)
     {
     case KCategorizedSortFilterProxyModel::CategorySortRole:
@@ -243,6 +265,9 @@ void ResourceModel::connectToKeyboardLayout(DataIndexKeyboardLayout *keyboardLay
 
 void ResourceModel::updateMappings()
 {
+    if (!m_dataIndex)
+        return;
+
     for (int i = 0; i < m_dataIndex->courseCount(); i++)
     {
         m_signalMapper->setMapping(m_dataIndex->course(i), i);
@@ -258,7 +283,7 @@ void ResourceModel::updateMappings()
 
 QIcon ResourceModel::resourceIcon(DataIndex::Source source) const
 {
-    static QIcon systemIcon = KIcon("computer");
-    static QIcon userIcon = KIcon("user-identity");
+    static QIcon systemIcon = QIcon::fromTheme("computer");
+    static QIcon userIcon = QIcon::fromTheme("user-identity");
     return source == DataIndex::BuiltInResource? systemIcon: userIcon;
 }
